import { Observable } from 'rxjs';
import { FactoryProvider, OnDestroy } from '@angular/core';
import { DateAdapter } from '@ng-tangram/components/core';
export declare class DateRange<D> {
    readonly start: D | null;
    readonly end: D | null;
    private _disableStructuralEquivalency;
    constructor(start: D | null, end: D | null);
}
export declare type ExtractDateTypeFromSelection<T> = T extends DateRange<infer D> ? D : NonNullable<T>;
export interface DateSelectionModelChange<S> {
    selection: S;
    source: unknown;
}
export declare abstract class NtDateSelectionModel<S, D = ExtractDateTypeFromSelection<S>> implements OnDestroy {
    readonly selection: S;
    protected _adapter: DateAdapter<D>;
    private _selectionChanged;
    selectionChanged: Observable<DateSelectionModelChange<S>>;
    protected constructor(selection: S, _adapter: DateAdapter<D>);
    updateSelection(value: S, source: unknown): void;
    ngOnDestroy(): void;
    protected _isValidDateInstance(date: D): boolean;
    abstract add(date: D | null): void;
    abstract isValid(): boolean;
    abstract isComplete(): boolean;
}
export declare class NtSingleDateSelectionModel<D> extends NtDateSelectionModel<D | null, D> {
    constructor(adapter: DateAdapter<D>);
    add(date: D | null): void;
    isValid(): boolean;
    isComplete(): boolean;
}
export declare class NtRangeDateSelectionModel<D> extends NtDateSelectionModel<DateRange<D>, D> {
    constructor(adapter: DateAdapter<D>);
    add(date: D | null): void;
    isValid(): boolean;
    isComplete(): boolean;
}
export declare function NT_SINGLE_DATE_SELECTION_MODEL_FACTORY(parent: NtSingleDateSelectionModel<unknown>, adapter: DateAdapter<unknown>): NtSingleDateSelectionModel<unknown>;
export declare const NT_SINGLE_DATE_SELECTION_MODEL_PROVIDER: FactoryProvider;
export declare function NT_RANGE_DATE_SELECTION_MODEL_FACTORY(parent: NtSingleDateSelectionModel<unknown>, adapter: DateAdapter<unknown>): NtSingleDateSelectionModel<unknown>;
export declare const NT_RANGE_DATE_SELECTION_MODEL_PROVIDER: FactoryProvider;
